# Generated by Django 2.2.18 on 2021-08-01 00:46

import django.db.models.deletion
import enumfields.fields
import parler.fields
from django.db import migrations, models

import shuup.core.fields
import shuup.core.models._product_catalog
import shuup.utils.properties


class Migration(migrations.Migration):

    dependencies = [
        ('shuup', '0093_fix_attr_m2m'),
    ]

    operations = [
        migrations.AlterField(
            model_name='productattribute',
            name='chosen_options',
            field=models.ManyToManyField(blank=True, to='shuup.AttributeChoiceOption', verbose_name='chosen options'),
        ),
        migrations.AlterField(
            model_name='productmedia',
            name='public',
            field=models.BooleanField(blank=True, db_index=True, default=True, help_text='Enable this if you want this image be shown on the product page. Enabled by default.', verbose_name='public (shown on product page)'),
        ),
        migrations.AlterField(
            model_name='salesunittranslation',
            name='master',
            field=parler.fields.TranslationsForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='translations', to='shuup.SalesUnit'),
        ),
        migrations.CreateModel(
            name='ProductCatalogPriceRule',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('module_identifier', models.CharField(max_length=100, verbose_name='Pricing module identifier')),
                ('contact', models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='catalog_prices', to='shuup.Contact')),
                ('contact_group', models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='catalog_prices', to='shuup.ContactGroup')),
            ],
            options={
                'unique_together': {('module_identifier', 'contact_group', 'contact')},
            },
        ),
        migrations.CreateModel(
            name='ProductCatalogDiscountedPriceRule',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('module_identifier', models.CharField(max_length=100, verbose_name='Discount module identifier')),
                ('valid_start_date', models.DateTimeField(blank=True, null=True, verbose_name='Valid start date and time')),
                ('valid_end_date', models.DateTimeField(blank=True, null=True, verbose_name='Valid end date and time')),
                ('valid_start_hour', models.TimeField(blank=True, null=True, verbose_name='Valid start hour')),
                ('valid_end_hour', models.TimeField(blank=True, null=True, verbose_name='Valid end hour')),
                ('valid_weekday', enumfields.fields.EnumIntegerField(blank=True, enum=shuup.core.models._product_catalog.WeekDay, null=True, verbose_name='Valid weekday')),
                ('contact', models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='catalog_discounted_prices', to='shuup.Contact')),
                ('contact_group', models.ForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='catalog_discounted_prices', to='shuup.ContactGroup')),
            ],
        ),
        migrations.CreateModel(
            name='ProductCatalogDiscountedPrice',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False)),
                ('discounted_price_value', shuup.core.fields.MoneyValueField(decimal_places=9, editable=False, help_text='The indexed discounted product price.', max_digits=36, null=True, verbose_name='discounted price')),
                ('catalog_rule', models.ForeignKey(help_text='The rule in which this discounted price is available.', on_delete=django.db.models.deletion.CASCADE, to='shuup.ProductCatalogDiscountedPriceRule', verbose_name='Catalog rule')),
                ('product', models.ForeignKey(editable=False, on_delete=django.db.models.deletion.CASCADE, related_name='catalog_discounted_prices', to='shuup.Product')),
                ('shop', models.ForeignKey(editable=False, on_delete=django.db.models.deletion.CASCADE, related_name='catalog_discounted_prices', to='shuup.Shop')),
                ('supplier', models.ForeignKey(editable=False, on_delete=django.db.models.deletion.CASCADE, related_name='catalog_discounted_prices', to='shuup.Supplier')),
            ],
            bases=(shuup.utils.properties.MoneyPropped, models.Model),
        ),
        migrations.CreateModel(
            name='ProductCatalogPrice',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False)),
                ('price_value', shuup.core.fields.MoneyValueField(decimal_places=9, editable=False, help_text='The indexed product price', max_digits=36, verbose_name='price')),
                ('is_available', models.BooleanField(db_index=True, default=False, editable=False, help_text='Whether the product is available for purchasing. This status is managed by the supplier module.', verbose_name='is available')),
                ('catalog_rule', models.ForeignKey(blank=True, help_text='The rule in which this price is available.', null=True, on_delete=django.db.models.deletion.CASCADE, to='shuup.ProductCatalogPriceRule', verbose_name='Catalog rule')),
                ('product', models.ForeignKey(editable=False, on_delete=django.db.models.deletion.CASCADE, related_name='catalog_prices', to='shuup.Product')),
                ('shop', models.ForeignKey(editable=False, on_delete=django.db.models.deletion.CASCADE, related_name='catalog_prices', to='shuup.Shop')),
                ('supplier', models.ForeignKey(editable=False, on_delete=django.db.models.deletion.CASCADE, related_name='catalog_prices', to='shuup.Supplier')),
            ],
            options={
                'unique_together': {('product', 'shop', 'supplier', 'catalog_rule')},
            },
            bases=(shuup.utils.properties.MoneyPropped, models.Model),
        ),
        migrations.AddIndex(
            model_name='productcatalogdiscountedpricerule',
            index=models.Index(fields=['module_identifier', 'contact_group', 'contact'], name='shuup_produ_module__729fa8_idx'),
        ),
        migrations.AddIndex(
            model_name='productcatalogdiscountedpricerule',
            index=models.Index(fields=['valid_start_date', 'valid_end_date', 'valid_start_hour', 'valid_end_hour', 'valid_weekday'], name='shuup_produ_valid_s_80070b_idx'),
        ),
        migrations.AlterUniqueTogether(
            name='productcatalogdiscountedprice',
            unique_together={('product', 'shop', 'supplier', 'catalog_rule')},
        ),
    ]
